bayespy.nodes.Beta
==================

.. currentmodule:: bayespy.nodes

.. autoclass:: Beta

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~Beta.__init__
      ~Beta.add_plate_axis
      ~Beta.broadcasting_multiplier
      ~Beta.delete
      ~Beta.get_gradient
      ~Beta.get_mask
      ~Beta.get_moments
      ~Beta.get_parameters
      ~Beta.get_riemannian_gradient
      ~Beta.get_shape
      ~Beta.has_plotter
      ~Beta.initialize_from_parameters
      ~Beta.initialize_from_prior
      ~Beta.initialize_from_random
      ~Beta.initialize_from_value
      ~Beta.load
      ~Beta.logpdf
      ~Beta.lower_bound_contribution
      ~Beta.lowerbound
      ~Beta.move_plates
      ~Beta.observe
      ~Beta.pdf
      ~Beta.plot
      ~Beta.random
      ~Beta.save
      ~Beta.set_parameters
      ~Beta.set_plotter
      ~Beta.show
      ~Beta.unobserve
      ~Beta.update
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: generated/
   
      ~Beta.dims
      ~Beta.plates
      ~Beta.plates_multiplier
   
   